pilot.impl.pilotdata_manager.PilotDataService

Package pilot :: Package impl :: Module pilotdata_manager :: Class PilotDataService |

# Class PilotDataService

source code

PilotDataService (PDS).

Factory for creating Pilot Data.

Instance Methods
__init__(self, coordination_url=`'``redis://localhost``'`, pds_url=None) Create a PilotDataService | source code
create_pilot(self, pilot_data_description) Create a PilotData | source code
get_pilot(self, pd_id) Reconnect to an existing pilot. | source code
list_pilots(self) List all PDs of PDS | source code
cancel(self) Cancel the PilotDataService. | source code
wait(self) Wait until all managed PD (of this Pilot Data Service) enter a final state | source code
get_url(self) Returns URL of Pilot Data Service | source code
to_dict(self) Return a Python dictionary containing the representation of the PDS (internal method not part of Pilot API) | source code
__del__(self) Releases all Pilot Data created by this Pilot Data Service. | source code
Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables
| PDS_ID_PREFIX = ``'``pds-``'``

Properties
| id (Inherited from pilot.api.data.api.PilotDataService)
| pilot_data (Inherited from pilot.api.data.api.PilotDataService)
| state (Inherited from pilot.api.data.api.PilotDataService)
Inherited from `object`: `__class__`

Method Details

### __init__(self, coordination_url=`'``redis://localhost``'`, pds_url=None) (Constructor) | source code
Create a PilotDataService Keyword arguments: pds_id -- restore from pds_id Overrides: object.__init__

### create_pilot(self, pilot_data_description) | source code
Create a PilotData Keyword arguments: pilot_data_description -- PilotData Description:
       {
           'service_url': "ssh://<hostname>/base-url/",
           'size': "1000"
       }
Return value: A PilotData object Overrides: api.data.api.PilotDataService.create_pilot

### list_pilots(self) | source code
List all PDs of PDS Overrides: api.data.api.PilotDataService.list_pilots

### cancel(self) | source code
Cancel the PilotDataService. Release all Pilot Data created by this service. Keyword arguments: None Return value: Result of operation Overrides: api.data.api.PilotDataService.cancel